========================
rest-solace Docs [WIP]
========================


List of topics:
    | `Getting started with Solace <https://github.com/skyler-guha/rest-solace/blob/master/docs/getting_started_with_solace.rst/>`_
    | MessagingPublisher
    | Manager
    | Consumer